/// <reference path='fourslash.ts'/>

////interface I {
////    [x: number]: string;
////    [x: number]: number;
////}

////var i: I;
////var /**/r = i[1];

goTo.marker();
verify.quickInfoIs('var r: string');
